import  {BaseElement, Animation} from "./smart.element"

export interface RibbonProperties {
  /**
   * Determines the animation type.
   * Default value: default
   */
  animationType?: RibbonAnimationType | string;
  /**
   * Determines whether the ribbon is collapsible.
   * Default value: false
   */
  collapsible?: any;
  /**
   * Determines the selected tab.
   * Default value: 0
   */
  selectedTab?: any;
  /**
   * Determines the tab items of the ribbon.
   * Default value: 
   */
  dataSource?: any;
  /**
   * Determines the file menu options of the ribbon.
   * Default value: [object Object]
   */
  fileMenu?: RibbonFileMenu;
  /**
   * Determines the locale of the ribbon.
   * Default value: "en"
   */
  locale?: string;
  /**
   * Determines the messages of the ribbon
   * Default value:    * [object Object]
   */
  messages?: any;
}
/**
 Ribbon is a navigation control that allows you to organize your application's commands in a tabbed interface.
*/
export interface Ribbon extends BaseElement, RibbonProperties {

  /* Get a member by its name */
  [name: string]: any;
  /**
   * This event is triggered when the tab selection is changed.
	* @param event. The custom event. Custom data event was created with: ev.detail(oldIndex, index)
   *  oldIndex - The previous tab index.
   *  index - The new index of the selected tab.
   */
  onChange: ((this: any, ev: Event) => any) | null;
  /**
   * This event is triggered when the tab selection is changing. The event can be canceled by calling event.preventDefault() in the event handler function.
	* @param event. The custom event. Custom data event was created with: ev.detail(oldIndex, index)
   *  oldIndex - The previous tab index.
   *  index - The new index of the selected tab.
   */
  onChanging?: ((this: any, ev: Event) => any) | ((this: any, ev: CustomEvent<any>) => any) | null;
  /**
   * This event is triggered when the dialog launcher is clicked.
	* @param event. The custom event. Custom data event was created with: ev.detail(id)
   *  id - The id of the dialog launcher's ribbon group.
   */
  onDialogLauncherClick?: ((this: any, ev: Event) => any) | ((this: any, ev: CustomEvent<any>) => any) | null;
  /**
   * This event is triggered when a ribbon item is clicked.
	* @param event. The custom event. Custom data event was created with: ev.detail(id, ribbonGroup, value)
   *  id - The id of the ribbon item.
   *  ribbonGroup - The ribbon group of the ribbon item.
   *  value - The value of the ribbon item.
   */
  onItemClick?: ((this: any, ev: Event) => any) | ((this: any, ev: CustomEvent<any>) => any) | null;
  /**
   * This event is triggered when the file menu button is clicked.
	* @param event. The custom event.    */
  onFileButtonClick?: ((this: any, ev: Event) => any) | ((this: any, ev: CustomEvent<any>) => any) | null;
  /**
   * This event is triggered when the file menu is opened.
	* @param event. The custom event.    */
  onFileMenuOpen?: ((this: any, ev: Event) => any) | ((this: any, ev: CustomEvent<any>) => any) | null;
  /**
   * This event is triggered when the file menu is closed.
	* @param event. The custom event.    */
  onFileMenuClose?: ((this: any, ev: Event) => any) | ((this: any, ev: CustomEvent<any>) => any) | null;
  /**
   * This event is triggered when a file menu item is clicked.
	* @param event. The custom event. Custom data event was created with: ev.detail(item)
   *  item - The file menu item.
   */
  onFileMenuItemClick?: ((this: any, ev: Event) => any) | ((this: any, ev: CustomEvent<any>) => any) | null;
  /**
   * This event is triggered when the ribbon is collapsed.
	* @param event. The custom event.    */
  onCollapse?: ((this: any, ev: Event) => any) | ((this: any, ev: CustomEvent<any>) => any) | null;
  /**
   * This event is triggered when the ribbon is collapsing. The event can be canceled by calling event.preventDefault() in the event handler function.
	* @param event. The custom event.    */
  onCollapsing?: ((this: any, ev: Event) => any) | ((this: any, ev: CustomEvent<any>) => any) | null;
  /**
   * This event is triggered when the ribbon is expanded.
	* @param event. The custom event.    */
  onExpand?: ((this: any, ev: Event) => any) | ((this: any, ev: CustomEvent<any>) => any) | null;
  /**
   * This event is triggered when the ribbon is expanding. The event can be canceled by calling event.preventDefault() in the event handler function.
	* @param event. The custom event.    */
  onExpanding?: ((this: any, ev: Event) => any) | ((this: any, ev: CustomEvent<any>) => any) | null;
  /**
   * Adds a new ribbon tab to the ribbon.
   * @param {any} ribbonTab. The ribbon tab to be added.
   */
  addRibbonTab(ribbonTab: any): void;
  /**
   * Adds a new ribbon group to a ribbon tab.
   * @param {any} ribbonGroup. The ribbon group to be added.
   * @param {string | number} ribbonTabIndex. The id or index of the parent ribbon tab.
   */
  addRibbonGroup(ribbonGroup: any, ribbonTabIndex: string | number): void;
  /**
   * Adds a new ribbon item to a ribbon group.
   * @param {any} ribbonItem. The ribbon item to be added.
   * @param {string | number} ribbonGroup. The id or index of the parrent ribbon group.
   * @param {string | number} ribbonTabIndex?. The id or index of the parent ribbon tab.
   */
  addRibbonItem(ribbonItem: any, ribbonGroup: string | number, ribbonTabIndex?: string | number): void;
  /**
   * Removes a ribbon tab from the ribbon.
   * @param {string | number} ribbonTabIndex. The id or index of the ribbon tab to be removed.
   */
  removeRibbonTab(ribbonTabIndex: string | number): void;
  /**
   * Removes a ribbon group from a ribbon tab.
   * @param {string | number} ribbonGroup. The id or index of the ribbon group to be removed.
   * @param {string | number} ribbonTabIndex?. The id or index of the parent ribbon tab.
   */
  removeRibbonGroup(ribbonGroup: string | number, ribbonTabIndex?: string | number): void;
  /**
   * Removes a ribbon item from a ribbon group.
   * @param {string | number} ribbonItem. The id or index of the ribbon item to be removed.
   * @param {string | number} ribbonGroup?. The id or index of the parent ribbon group.
   * @param {string | number} ribbonTabIndex?. The id or index of the parent ribbon tab.
   */
  removeRibbonItem(ribbonItem: string | number, ribbonGroup?: string | number, ribbonTabIndex?: string | number): void;
  /**
   * Selects a ribbon tab.
   * @param {string | number} ribbonTabIndex. The id or index of the ribbon tab to be selected.
   */
  selectTab(ribbonTabIndex: string | number): void;
  /**
   * Collapses the ribbon.
   */
  collapse(): void;
  /**
   * Expands the ribbon.
   */
  expand(): void;
  /**
   * Disables a ribbon tab.
   * @param {string | number} ribbonTabIndex. The id or index of the ribbon tab to be disabled.
   */
  disableRibbonTab(ribbonTabIndex: string | number): void;
  /**
   * Enables a ribbon tab.
   * @param {string | number} ribbonTabIndex. The id or index of the ribbon tab to be enabled.
   */
  enableRibbonTab(ribbonTabIndex: string | number): void;
  /**
   * Disables a ribbon group.
   * @param {string | number} ribbonTabIndex. The id or index of the parent ribbon tab.
   * @param {string | number} ribbonGroup?. The id or index of the ribbon group to be disabled.
   */
  disableRibbonGroup(ribbonTabIndex: string | number, ribbonGroup?: string | number): void;
  /**
   * Enables a ribbon group.
   * @param {string | number} ribbonTabIndex. The id or index of the parent ribbon tab.
   * @param {string | number} ribbonGroup?. The id or index of the ribbon group to be enabled.
   */
  enableRibbonGroup(ribbonTabIndex: string | number, ribbonGroup?: string | number): void;
  /**
   * Disables a ribbon item.
   * @param {string | number} ribbonTabIndex. The id or index of the parent ribbon tab.
   * @param {string | number} ribbonGroup?. The id or index of the parent ribbon group.
   * @param {string | number} ribbonItem?. The id or index of the ribbon item to be disabled.
   */
  disableRibbonItem(ribbonTabIndex: string | number, ribbonGroup?: string | number, ribbonItem?: string | number): void;
  /**
   * Enables a ribbon item.
   * @param {string | number} ribbonTabIndex. The id or index of the parent ribbon tab.
   * @param {string | number} ribbonGroup?. The id or index of the parent ribbon group.
   * @param {string | number} ribbonItem?. The id or index of the ribbon item to be enabled.
   */
  enableRibbonItem(ribbonTabIndex: string | number, ribbonGroup?: string | number, ribbonItem?: string | number): void;
}

/**Determines the file menu options of the ribbon. */
export interface RibbonFileMenu {
  /**
   * Determines whether the file button is enabled.
   * Default value: true
   */
  enabled?: boolean;
  /**
   * Determines the data source that will be loaded to the FileMenu.
   * Default value: 
   */
  items?: any;
  /**
   * Determines the position of the file menu.
   * Default value: left
   */
  position?: RibbonFileMenuPosition | string;
  /**
   * Determines the tooltip of the file menu.
   * Default value: ""
   */
  tooltip?: string;
  /**
   * Determines the template of the file menu. Accepts HTMLTemplateElement, an id of an HTMLTemplateElement or a Function.
   * Default value: ""
   */
  template?: string;
  /**
   * Determines the type of the file menu.
   * Default value: dropDown
   */
  type?: RibbonFileMenuType | string;
  /**
   * Determines the icon of the file menu.
   * Default value: ""
   */
  icon?: string;
}

declare global {
    interface Document {
        createElement(tagName: "smart-ribbon"): Ribbon;
        querySelector(selectors: "smart-ribbon"): Ribbon | null;
        querySelectorAll(selectors: "smart-ribbon"): NodeListOf<Ribbon>;
        getElementsByTagName(qualifiedName: "smart-ribbon"): HTMLCollectionOf<Ribbon>;
        getElementsByName(elementName: "smart-ribbon"): NodeListOf<Ribbon>;
    }
}

/**Determines the animation type. */
export declare type RibbonAnimationType = 'slide' | 'fade';
/**Determines the position of the file menu. */
export declare type RibbonFileMenuPosition = 'left' | 'right';
/**Determines the type of the file menu. */
export declare type RibbonFileMenuType = 'dropDown' | 'button';
